==> flowable-dmn-engine-6.3.0-sources.jar: org/flowable/dmn/engine/impl/cmd/GetDeploymentDmnResourceCmd.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.flowable.dmn.engine.impl.cmd;

import java.io.InputStream;
import java.io.Serializable;

import org.flowable.dmn.engine.impl.persistence.entity.DecisionTableEntity;
import org.flowable.dmn.engine.impl.util.CommandContextUtil;
import org.flowable.engine.common.api.FlowableIllegalArgumentException;
import org.flowable.engine.common.impl.interceptor.Command;
import org.flowable.engine.common.impl.interceptor.CommandContext;

/**
 * Gives access to a deployed decision table model, e.g., a DMN XML file, through a stream of bytes.
 * 
 * @author Tijs Rademakers
 */
public class GetDeploymentDmnResourceCmd implements Command<InputStream>, Serializable {

    private static final long serialVersionUID = 1L;
    protected String decisionTableId;

    public GetDeploymentDmnResourceCmd(String decisionTableId) {
        if (decisionTableId == null || decisionTableId.length() < 1) {
            throw new FlowableIllegalArgumentException("The decision table id is mandatory, but '" + decisionTableId + "' has been provided.");
        }
        this.decisionTableId = decisionTableId;
    }

    @Override
    public InputStream execute(CommandContext commandContext) {
        DecisionTableEntity decisionTable = CommandContextUtil.getDmnEngineConfiguration().getDeploymentManager().findDeployedDecisionById(decisionTableId);
        String deploymentId = decisionTable.getDeploymentId();
        String resourceName = decisionTable.getResourceName();
        InputStream processModelStream = new GetDeploymentResourceCmd(deploymentId, resourceName).execute(commandContext);
        return processModelStream;
    }

}

==> flowable-dmn-engine-6.4.0-sources.jar: org/flowable/dmn/engine/impl/cmd/GetDeploymentDmnResourceCmd.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.flowable.dmn.engine.impl.cmd;

import java.io.InputStream;
import java.io.Serializable;

import org.flowable.common.engine.api.FlowableIllegalArgumentException;
import org.flowable.common.engine.impl.interceptor.Command;
import org.flowable.common.engine.impl.interceptor.CommandContext;
import org.flowable.dmn.engine.impl.persistence.entity.DecisionTableEntity;
import org.flowable.dmn.engine.impl.util.CommandContextUtil;

/**
 * Gives access to a deployed decision table model, e.g., a DMN XML file, through a stream of bytes.
 * 
 * @author Tijs Rademakers
 */
public class GetDeploymentDmnResourceCmd implements Command<InputStream>, Serializable {

    private static final long serialVersionUID = 1L;
    protected String decisionTableId;

    public GetDeploymentDmnResourceCmd(String decisionTableId) {
        if (decisionTableId == null || decisionTableId.length() < 1) {
            throw new FlowableIllegalArgumentException("The decision table id is mandatory, but '" + decisionTableId + "' has been provided.");
        }
        this.decisionTableId = decisionTableId;
    }

    @Override
    public InputStream execute(CommandContext commandContext) {
        DecisionTableEntity decisionTable = CommandContextUtil.getDmnEngineConfiguration().getDeploymentManager().findDeployedDecisionById(decisionTableId);
        String deploymentId = decisionTable.getDeploymentId();
        String resourceName = decisionTable.getResourceName();
        InputStream processModelStream = new GetDeploymentResourceCmd(deploymentId, resourceName).execute(commandContext);
        return processModelStream;
    }

}
